@@ -110,6 +110,14 @@ SessionManager::~SessionManager()
 
 void SessionManager::initConnections()
 {
+    // TODO: When the Active of login1 is changed to false,
+    // it will not cause the ActiveChanged signal to send
+    // because it is the same as the default value.
+    // This is a DTK bug and the default value is not initialized.
+    // Manually calling this interface will change the default default.
+    const bool active = m_login1SessionInter->active();
+    Q_UNUSED(active)
+
     connect(m_login1SessionInter, &org::freedesktop::login1::Session::ActiveChanged, [=](bool active) {
         qDebug() << "session active status changed to:" << active;
         if (active) {
@@ -418,10 +426,13 @@ void SessionManager::RequestHibernate()
         qWarning() << "failed to hibernate, error: " << reply.error().name();
     }
 
+    // TODO: if has quick-black-screen config, need use dde black screen, else use dpms mode
+    setDPMSMode(false);
+
     // NOTE: do we need it anymore?
-    if (Dconf::SetValue("com.deepin.dde.startdde", "", "quick-black-screen", false)) {
-        setDPMSMode(false);
-    }
+    // if (Dconf::SetValue("com.deepin.dde.startdde", "", "quick-black-screen", false)) {
+    //     setDPMSMode(false);
+    // }
 }
 
 void SessionManager::RequestLock()
@@ -760,7 +771,7 @@ void SessionManager::playLoginSound()
         return;
 
     qInfo() << "play system sound: desktop-login";
-    playSound("desktop-login");
+    playSoundAutoLogin("desktop-login");
 
     // 播放后创建文件
     QFile file(markFile);
@@ -794,7 +805,7 @@ void SessionManager::playLogoutSound()
     // 始终在注销前退出pulseaudio服务
     stopPulseAudioService();
 
-    playSound("desktop-logout");
+    playSoundLogout("desktop-logout");
 }
 
 void SessionManager::setDPMSMode(bool on)
@@ -872,6 +883,8 @@ void SessionManager::emitLockChanged(bool locked)
    arguments.push_back(QStringList());
    msg.setArguments(arguments);
    QDBusConnection::sessionBus().send(msg);
+
+   Q_EMIT LockedChanged(locked);
 }
 
 void SessionManager::emitStageChanged(int state)
@@ -892,7 +905,19 @@ void SessionManager::emitCurrentUidChanged(QString uid)
      // 这个属性不会变化
 }
 
-inline void SessionManager::playSound(const QString &event)
+// 自动登录时session已经启动了，不能使用alsa，会和通过pa或者pipewire抢占通道，导致音频模块异常
+inline void SessionManager::playSoundAutoLogin(const QString &event)
+{
+    QDBusInterface soundPlayerInter("org.deepin.dde.SoundEffect1", "/org/deepin/dde/SoundEffect1",
+        "org.deepin.dde.SoundEffect1", QDBusConnection::sessionBus());
+    QDBusMessage reply = soundPlayerInter.call("PlaySound", event);
+    if (reply.type() == QDBusMessage::ErrorMessage) {
+        qWarning() << "Failed to call Play:" << event << reply.errorMessage();
+    }
+}
+
+// 注销时，不能使用pa或者pipewire，因为session可能会退出，导致没有音效，应该直接使用alsa
+inline void SessionManager::playSoundLogout(const QString &event)
 {
     QDBusInterface soundPlayerInter("org.deepin.dde.SoundThemePlayer1", "/org/deepin/dde/SoundThemePlayer1",
         "org.deepin.dde.SoundThemePlayer1", QDBusConnection::systemBus());
