@@ -112,6 +112,8 @@ private:
     void emitStageChanged(int);
     void emitCurrentSessionPathChanged(QDBusObjectPath);
     void emitCurrentUidChanged(QString);
+    void playSoundAutoLogin(const QString& event);
+    void playSoundLogout(const QString& event);
 
     void playSound(const QString &event);
 
@@ -121,6 +123,7 @@ private Q_SLOTS:
 
 signals:
     // signals on dbus
+    void LockedChanged(bool locked);
     void Unlock();
     void InhibitorAdded(const QDBusObjectPath &);
     void InhibitorRemoved(const QDBusObjectPath &);
