@@ -23,7 +23,6 @@
 #include "wmswitcher1adaptor.h"
 #include "org_freedesktop_systemd1_Manager.h"
 #include "utils/fifo.h"
-#include "utils/utils.h"
 #include "impl/sessionmanager.h"
 #include "impl/wmswitcher.h"
 #include "impl/iowait/iowaitwatcher.h"
@@ -81,6 +80,8 @@ int main(int argc, char *argv[])
     parser.addOption(systemd);
     parser.process(app);
 
+    DLogManager::registerJournalAppender();
+
     if (!parser.isSet(systemd)) {
         DLogManager::registerConsoleAppender();
         DLogManager::registerFileAppender();
@@ -99,7 +100,7 @@ int main(int argc, char *argv[])
             qApp->quit();
         });
         pid_t curPid = getpid();
-        QtConcurrent::run([curPid](){
+        QThreadPool::globalInstance()->start([curPid]() {
             qInfo()<<"leader pipe thread id: " << QThread::currentThreadId() << ", pid: " << curPid;
             Fifo *fifo = new Fifo;
             fifo->OpenWrite();
@@ -110,7 +111,11 @@ int main(int argc, char *argv[])
         return app.exec();
     }
 
-    // systemd-service
+    /* ---systemd-service--- */
+
+    // QProcess no block "/usr/bin/deepin-keyring-whitebox", "--opt-client=waitfifonotify"),BUG-255907
+    QProcess::startDetached("/usr/bin/deepin-keyring-whitebox", QStringList() << "--opt-client=waitfifonotify");
+
     auto* session = new Session;
     new Session1Adaptor(session);
     QDBusConnection::sessionBus().registerService("org.deepin.dde.Session1");
@@ -127,7 +132,7 @@ int main(int argc, char *argv[])
     QDBusConnection::sessionBus().registerObject("/org/deepin/dde/WMSwitcher1", wmSwitcher);
 
     // TODO 这部分都是一次性运行，可以拆分成不同的oneshot服务
-    QtConcurrent::run([] {
+    QThreadPool::globalInstance()->start([] {
         OthersManager().init();
     });
 
@@ -144,7 +149,7 @@ int main(int argc, char *argv[])
 #endif
     qInfo() << "iowait watcher disabled";
 
-    QtConcurrent::run([&session](){
+    QThreadPool::globalInstance()->start([&session]() {
         qInfo()<< "systemd service pipe thread id: " << QThread::currentThreadId();
         Fifo *fifo = new Fifo;
         fifo->OpenRead();
